/****************************************************************
 *								*
 * Copyright (c) 2003-2018 Fidelity National Information	*
 * Services, Inc. and/or its subsidiaries. All rights reserved.	*
 *								*
 *	This source code contains the intellectual property	*
 *	of its copyright holder(s), and is made available	*
 *	under a license.  If you do not know the terms of	*
 *	the license, please stop and do not read further.	*
 *								*
 ****************************************************************/

#ifndef GTM_FILE_REMOVE_H_INCLUDED
#define GTM_FILE_REMOVE_H_INCLUDED
int4 gtm_file_remove(char *fn, int fn_len, uint4 *ustatus);

#endif
